@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 16.1.2 Debian package creator
-# Release 2019-12-17
+# DaVinci Resolve 16.2 Debian package creator
+# Release 2020-03-06
 # By Daniel Tufvesson
 #
 
@@ -57,7 +57,7 @@ make_executable() {
 }
 
 # Setup variables
-RESOLVE_VERSION=16.1.2
+RESOLVE_VERSION=16.2
 DEB_STEPPING=1
 case $1 in
     studio)
@@ -91,11 +91,18 @@ if [ ! -e "${INSTALLER_ARCHIVE}" ] ; then
     echo "Sorry. Need '${INSTALLER_ARCHIVE}' to continue. Download the archive from www.blackmagicdesign.com"
     exit 1
 fi
+if [ -e "${UNPACK_DIR}" ] ; then
+    chmod a+w -R ${UNPACK_DIR}
+    rm -rf ${UNPACK_DIR}
+fi
 create_directory ${UNPACK_DIR}
 check_command xorriso
 xorriso -osirrox on -indev ${INSTALLER_ARCHIVE} -extract / ${UNPACK_DIR}
 
 # Create destination directories
+if [ -e "${UNPACK_DIR}" ] ; then
+    rm -rf ${DEB_DIR}
+fi
 create_directory ${DEB_DIR}
 create_directory ${RESOLVE_BASE_DIR}
 
